@@ -12,7 +12,7 @@ from os import path
 from cdd import emit, parse
 from cdd.ast_utils import get_at_root, maybe_type_comment, set_value
 from cdd.parser_utils import infer
-from cdd.pure_utils import get_module
+from cdd.pure_utils import get_module, sanitise_emit_name
 from cdd.source_transformer import to_code
 
 
@@ -27,6 +27,7 @@ def gen(
     emit_call=False,
     emit_default_doc=True,
     decorator_list=None,
+    no_word_wrap=None,
 ):
     """
     Generate classes, functions, and/or argparse functions from the input mapping
@@ -61,6 +62,9 @@ def gen(
 
     :param decorator_list: List of decorators
     :type decorator_list: ```Optional[Union[List[Str], List[]]]```
+
+    :param no_word_wrap: Whether word-wrap is disabled (on emission).
+    :type no_word_wrap: ```Optional[Literal[True]]```
     """
     extra_symbols = {}
     if imports_from_file is None:
@@ -78,7 +82,7 @@ def gen(
             #     :param node: import node
             #     :type node: ```Union[Import, ImportFrom]```
             #
-            #     :returns: The import potentially rewritten or None
+            #     :return: The import potentially rewritten or None
             #     :rtype: ```Optional[Union[Import, ImportFrom]]```
             #     """
             #     if isinstance(node, ImportFrom) and node.module == "typing":
@@ -150,14 +154,12 @@ def gen(
     )
 
     global__all__ = []
-    emit_name = emit_name.replace("class", "class_").replace(
-        "argparse", "argparse_function"
-    )
-    content = "{prepend}{imports}\n{functions_and_classes}\n{__all}".format(
+    emit_name = sanitise_emit_name(emit_name)
+    content = "{prepend}{imports}\n{functions_and_classes}\n{__all__}".format(
         prepend="" if prepend is None else prepend,
         imports=imports,  # TODO: Optimize imports programmatically (akin to `autoflake --remove-all-unused-imports`)
         functions_and_classes="\n\n".join(
-            print("\nGenerating: {!r}".format(name))
+            print("\nGenerating: {name!r}".format(name=name))
             or global__all__.append(name_tpl.format(name=name))
             or to_code(
                 getattr(emit, emit_name)(
@@ -166,9 +168,10 @@ def gen(
                         infer(obj) if parse_name in (None, "infer") else parse_name,
                     )(obj),
                     emit_default_doc=emit_default_doc,
+                    word_wrap=no_word_wrap is None,
                     **(
                         lambda _name: {
-                            "argparse": {"function_name": _name},
+                            "argparse_function": {"function_name": _name},
                             "class_": {
                                 "class_name": _name,
                                 "decorator_list": decorator_list,
@@ -185,7 +188,7 @@ def gen(
             )
             for name, obj in input_mapping_it
         ),
-        __all=to_code(
+        __all__=to_code(
             Assign(
                 targets=[Name("__all__", Store())],
                 value=ast.parse(  # `TypeError: Type List cannot be instantiated; use list() instead`
@@ -209,7 +212,7 @@ def gen(
 
     parsed_ast = ast.parse(content)
     # TODO: Shebang line first, then docstring, then imports
-    doc_str = ast.get_docstring(parsed_ast)
+    doc_str = ast.get_docstring(parsed_ast, clean=True)
     whole = tuple(
         map(
             lambda node: (node, None)
