@@ -35,8 +35,8 @@ from textwrap import indent
 
 from cdd.ast_utils import maybe_type_comment, set_arg, set_slice, set_value
 from cdd.defaults_utils import extract_default
-from cdd.pure_utils import tab
-from cdd.tests.mocks.docstrings import docstring_header_str
+from cdd.pure_utils import strip_starting, tab
+from cdd.tests.mocks.docstrings import docstring_header_str, docstring_reduction_v2_str
 from cdd.tests.mocks.methods import (
     function_google_tf_squared_hinge_docstring_str,
     returns_subscript,
@@ -310,7 +310,6 @@ class_nargs_ast = ClassDef(
             ),
             simple=1,
             target=Name("callbacks", Store()),
-            value=set_value(None),
             expr=None,
             expr_annotation=None,
             expr_target=None,
@@ -330,20 +329,8 @@ class_squared_hinge_config_ast = ClassDef(
             set_value(
                 "\n{tab}{doc}{tab}\n{args}".format(
                     tab=tab,
-                    # Inverse `emit_separating_tabs`
-                    doc="\n".join(
-                        map(
-                            lambda line: (
-                                ""
-                                if line.isspace() or not line
-                                else tab + line[2:]
-                                if len(line) > 2 and line[:2].isspace()
-                                else line
-                            ),
-                            remove_args_from_docstring(
-                                function_google_tf_squared_hinge_docstring_str
-                            ).splitlines(),
-                        ),
+                    doc=remove_args_from_docstring(
+                        function_google_tf_squared_hinge_docstring_str
                     ),
                     args="\n".join(
                         map(
@@ -650,7 +637,12 @@ tensorboard_doc_str_no_args = (
     "  ```",
 )
 
-tensorboard_doc_str_no_args_str = "\n".join(tensorboard_doc_str_no_args) + "\n"
+tensorboard_doc_str_no_args_str = "\n".join(
+    map(
+        partial(strip_starting, str_to_strip="  "),
+        tensorboard_doc_str_no_args,
+    )
+)
 
 tensorboard_doc_str_no_args_examples_idx = tensorboard_doc_str_no_args.index(
     "  Examples:"
@@ -690,15 +682,17 @@ tensorboard_doc_str_args = (
 )
 
 tensorboard_doc_str = "\n".join(
-    chain.from_iterable(
-        (
-            tensorboard_doc_str_no_args[:tensorboard_doc_str_no_args_examples_idx],
-            "",
-            tensorboard_doc_str_args,
-            ("\n",),
-            tensorboard_doc_str_no_args[tensorboard_doc_str_no_args_examples_idx:],
-            ("\n",),
-        )
+    map(
+        partial(strip_starting, str_to_strip="  "),
+        chain.from_iterable(
+            (
+                tensorboard_doc_str_no_args[:tensorboard_doc_str_no_args_examples_idx],
+                "",
+                tensorboard_doc_str_args,
+                ("\n",),
+                tensorboard_doc_str_no_args[tensorboard_doc_str_no_args_examples_idx:],
+            )
+        ),
     )
 )
 del tensorboard_doc_str_no_args_examples_idx
@@ -1136,7 +1130,7 @@ class_torch_nn_one_cycle_lr_docstring = (
 )
 class_torch_nn_one_cycle_lr_docstring_str = "\n".join(
     class_torch_nn_one_cycle_lr_docstring
-)
+)[: -len(tab)]
 
 class_torch_nn_one_cycle_lr = (
     "class OneCycleLR(_LRScheduler):",
@@ -1237,16 +1231,37 @@ class_torch_nn_one_cycle_lr_ast = ClassDef(
     name="OneCycleLR",
 )
 
+# From `tf.keras.losses.Reduction` @ tf-nightly:2.7.0.dev20210908, minus methods and decorator
+class_reduction_v2 = ClassDef(
+    name="ReductionV2",
+    bases=[],
+    keywords=[],
+    body=[
+        Expr(value=set_value(docstring_reduction_v2_str)),
+        Assign(targets=[Name(id="AUTO", ctx=Store())], value=set_value("auto")),
+        Assign(targets=[Name(id="NONE", ctx=Store())], value=set_value("none")),
+        Assign(targets=[Name(id="SUM", ctx=Store())], value=set_value("sum")),
+        Assign(
+            targets=[Name(id="SUM_OVER_BATCH_SIZE", ctx=Store())],
+            value=set_value("sum_over_batch_size"),
+        ),
+    ],
+    decorator_list=[],
+)
+
 __all__ = [
     "class_ast",
     "class_google_tf_tensorboard_ast",
     "class_google_tf_tensorboard_str",
     "class_nargs_ast",
     "class_nargs_str",
+    "class_reduction_v2",
     "class_squared_hinge_config_ast",
     "class_str",
     "class_torch_nn_l1loss_ast",
+    "class_torch_nn_l1loss_docstring_str",
     "class_torch_nn_l1loss_str",
-    "class_torch_nn_one_cycle_lr_str",
     "class_torch_nn_one_cycle_lr_ast",
+    "class_torch_nn_one_cycle_lr_str",
+    "tensorboard_doc_str_no_args_str",
 ]
